import setuptools

setuptools.setup(
    name="nanatou",
    version="0.0.1",
    author="Kayode Adechinan",
    author_email="kayode.adechinan@gmail.com",
    description="to my lover",
    packages=setuptools.find_packages(),
    license='MIT',
    zip_safe=False
)
